@@ -153,8 +153,6 @@ data.table::funion
 #' @export
 data.table::getDTthreads
 
-#' @export
-data.table::getNumericRounding
 
 #' @export
 data.table::haskey
@@ -187,12 +185,6 @@ data.table::rowidv
 #' @export
 data.table::set
 
-#' @export
-data.table::set2key
-
-#' @export
-data.table::set2keyv
-
 #' @export
 data.table::setattr
 
@@ -217,8 +209,6 @@ data.table::setkeyv
 #' @export
 data.table::setnames
 
-#' @export
-data.table::setNumericRounding
 
 #' @export
 data.table::setorder
@@ -238,18 +228,6 @@ data.table::tstrsplit
 #' @export
 data.table::uniqueN
 
-#' @export
-data.table::`%between%`
-
-#' @export
-data.table::`%chin%`
-
-#' @export
-data.table::`%inrange%`
-
-#' @export
-data.table::`%like%`
-
 
 #' @export
 htmlTable::htmlTable
@@ -273,4 +251,4 @@ htmlTable::interactiveTable
     if(rnd>0.8){
         packageStartupMessage("\nUse 'expss_output_rnotebook()' to display tables inside R Notebooks.\n To return to the console output, use 'expss_output_default()'.\n")
     }
-}
\ No newline at end of file
+}
