@@ -76,7 +76,7 @@ w_no_na = w[no_na]
 expect_equal(w_mean(x, w), weighted.mean(x, w_prep, na.rm = TRUE))
 expect_equal(w_sum(x, w), sum(x*w_prep, na.rm = TRUE))
 expect_equal(w_median(x, w),
-                 matrixStats:::weightedMedian(x_no_na, w_no_na, interpolate = TRUE, ties = "weighted"))
+                 matrixStats:::weightedMedian(x_no_na, w_no_na, interpolate = FALSE, ties = "weighted"))
 expect_equal(w_mad(x, w),
                  matrixStats:::weightedMad(x_no_na, w_no_na,  center = w_median(x, w, na.rm = TRUE)))
 expect_equal(w_sd(x, w), matrixStats:::weightedSd(x_no_na, w_no_na))
@@ -91,7 +91,7 @@ w = as.matrix(w)
 expect_equal(w_mean(x, w), weighted.mean(x, w_prep, na.rm = TRUE))
 expect_equal(w_sum(x, w), sum(x*w_prep, na.rm = TRUE))
 expect_equal(w_median(x, w),
-                 matrixStats:::weightedMedian(x_no_na, w_no_na, interpolate = TRUE, ties = "weighted"))
+                 matrixStats:::weightedMedian(x_no_na, w_no_na, interpolate = FALSE, ties = "weighted"))
 expect_equal(w_mad(x, w),
                  matrixStats:::weightedMad(x_no_na, w_no_na, center = w_median(x, w, na.rm = TRUE)))
 expect_equal(w_sd(x, w), matrixStats:::weightedSd(x_no_na, w_no_na))
@@ -137,7 +137,7 @@ w_prep2 = rep(w2, length(x))
 expect_equal(w_mean(x, w2), weighted.mean(x, w_prep2, na.rm = TRUE))
 expect_equal(w_sum(x, w2), sum(x*w_prep2, na.rm = TRUE))
 expect_equal(w_median(x, w2),
-                 matrixStats::weightedMedian(x, w_prep2, na.rm = TRUE, interpolate = TRUE, ties = "weighted"))
+                 matrixStats::weightedMedian(x, w_prep2, na.rm = TRUE, interpolate = FALSE, ties = "weighted"))
 expect_equal(w_mad(x, w2),
                  matrixStats::weightedMad(x, w_prep2, na.rm = TRUE, center = w_median(x, w_prep2, na.rm = TRUE)))
 expect_equal(w_sd(x, w2), matrixStats::weightedSd(x, w_prep2, na.rm = TRUE))
@@ -151,9 +151,11 @@ expect_equal(w_se(x, w2),
 data(iris)
 expect_equal(w_mean(x, w), 1.679588893639)
 expect_equal(w_sum(x, w), 13.633172662)
-# expect_equal(w_median(x, w), 1.78831) # compatibility with SPSS for weighted median is broken
-expect_equal(w_median(iris$Petal.Length), 4.35)
-expect_equal(w_median(iris$Petal.Length, weight = rep(1, 150)), 4.35)
+expect_equal(w_median(x, w), 1.78831) 
+if(as.numeric(version$major) >=4){
+    expect_equal(w_median(iris$Petal.Length), 4.4)
+    expect_equal(w_median(iris$Petal.Length, weight = rep(1, 150)), 4.4)
+}
 # expect_equal(w_mad(x, w), ???))
 expect_equal(w_sd(x, w), 0.2728535109892)
 expect_equal(w_var(x, w), 0.07444903845913)
@@ -172,7 +174,7 @@ w_no_na = w[no_na]
 expect_equal(w_mean(x, w, na.rm = FALSE), weighted.mean(x, w_prep, na.rm = TRUE))
 expect_equal(w_sum(x, w, na.rm = FALSE), sum(x*w_prep, na.rm = TRUE))
 expect_equal(w_median(x, w, na.rm = FALSE),
-                 matrixStats::weightedMedian(x_no_na, w_no_na, interpolate = TRUE, ties = "weighted"))
+                 matrixStats::weightedMedian(x_no_na, w_no_na, interpolate = FALSE, ties = "weighted"))
 expect_equal(w_mad(x, w, na.rm = FALSE),
                  matrixStats::weightedMad(x_no_na, w_no_na, center = w_median(x, w, na.rm = FALSE)))
 expect_equal(w_sd(x, w, na.rm = FALSE), matrixStats::weightedSd(x_no_na, w_no_na))
